> response =
api.getAuditLogs(timePeriod, cursor);
}
-
- /**
- * Get audit logs
- *
- * Get all audits
- *
- * @throws ApiException if the Api call fails
- */
- @Test
- public void getAuditsTest() throws ApiException {
- String timePeriod = null;
- CompletableFuture> response =
- api.getAudits(timePeriod);
- }
}
diff --git a/src/test/java/com/fireblocks/sdk/api/DeployedContractsApiTest.java b/src/test/java/com/fireblocks/sdk/api/DeployedContractsApiTest.java
index 11e0dcf..eb3ffa2 100644
--- a/src/test/java/com/fireblocks/sdk/api/DeployedContractsApiTest.java
+++ b/src/test/java/com/fireblocks/sdk/api/DeployedContractsApiTest.java
@@ -15,8 +15,11 @@
import com.fireblocks.sdk.ApiException;
import com.fireblocks.sdk.ApiResponse;
+import com.fireblocks.sdk.model.AddAbiRequestDto;
+import com.fireblocks.sdk.model.ContractWithAbiDto;
import com.fireblocks.sdk.model.DeployedContractResponseDto;
import com.fireblocks.sdk.model.DeployedContractsPaginatedResponse;
+import com.fireblocks.sdk.model.FetchAbiRequestDto;
import java.math.BigDecimal;
import java.util.concurrent.CompletableFuture;
import org.junit.Ignore;
@@ -28,6 +31,36 @@ public class DeployedContractsApiTest {
private final DeployedContractsApi api = new DeployedContractsApi();
+ /**
+ * Save contract ABI
+ *
+ * Save contract ABI for the tenant
+ *
+ * @throws ApiException if the Api call fails
+ */
+ @Test
+ public void addContractABITest() throws ApiException {
+ AddAbiRequestDto addAbiRequestDto = null;
+ String idempotencyKey = null;
+ CompletableFuture> response =
+ api.addContractABI(addAbiRequestDto, idempotencyKey);
+ }
+
+ /**
+ * Fetch the contract ABI
+ *
+ * Fetch the ABI. If not found fetch the ABI from the block explorer
+ *
+ * @throws ApiException if the Api call fails
+ */
+ @Test
+ public void fetchContractAbiTest() throws ApiException {
+ FetchAbiRequestDto fetchAbiRequestDto = null;
+ String idempotencyKey = null;
+ CompletableFuture> response =
+ api.fetchContractAbi(fetchAbiRequestDto, idempotencyKey);
+ }
+
/**
* Return deployed contract data
*
diff --git a/src/test/java/com/fireblocks/sdk/api/TokenizationApiTest.java b/src/test/java/com/fireblocks/sdk/api/TokenizationApiTest.java
index 6c47591..fdc0735 100644
--- a/src/test/java/com/fireblocks/sdk/api/TokenizationApiTest.java
+++ b/src/test/java/com/fireblocks/sdk/api/TokenizationApiTest.java
@@ -15,7 +15,14 @@
import com.fireblocks.sdk.ApiException;
import com.fireblocks.sdk.ApiResponse;
+import com.fireblocks.sdk.model.CollectionBurnRequestDto;
+import com.fireblocks.sdk.model.CollectionBurnResponseDto;
+import com.fireblocks.sdk.model.CollectionDeployRequestDto;
+import com.fireblocks.sdk.model.CollectionLinkDto;
+import com.fireblocks.sdk.model.CollectionMintRequestDto;
+import com.fireblocks.sdk.model.CollectionMintResponseDto;
import com.fireblocks.sdk.model.CreateTokenRequestDto;
+import com.fireblocks.sdk.model.GetLinkedCollectionsPaginatedResponse;
import com.fireblocks.sdk.model.TokenLinkDto;
import com.fireblocks.sdk.model.TokenLinkRequestDto;
import com.fireblocks.sdk.model.TokensPaginatedResponse;
@@ -30,6 +37,81 @@ public class TokenizationApiTest {
private final TokenizationApi api = new TokenizationApi();
+ /**
+ * Burn tokens
+ *
+ * Burn tokens in a collection
+ *
+ * @throws ApiException if the Api call fails
+ */
+ @Test
+ public void burnCollectionTokenTest() throws ApiException {
+ CollectionBurnRequestDto collectionBurnRequestDto = null;
+ String id = null;
+ String idempotencyKey = null;
+ CompletableFuture> response =
+ api.burnCollectionToken(collectionBurnRequestDto, id, idempotencyKey);
+ }
+
+ /**
+ * Create a new collection
+ *
+ * Create a new collection and link it as a token
+ *
+ * @throws ApiException if the Api call fails
+ */
+ @Test
+ public void createNewCollectionTest() throws ApiException {
+ CollectionDeployRequestDto collectionDeployRequestDto = null;
+ String idempotencyKey = null;
+ CompletableFuture> response =
+ api.createNewCollection(collectionDeployRequestDto, idempotencyKey);
+ }
+
+ /**
+ * Get collection token details
+ *
+ * Get collection token details by id
+ *
+ * @throws ApiException if the Api call fails
+ */
+ @Test
+ public void fetchCollectionTokenDetailsTest() throws ApiException {
+ String id = null;
+ String tokenId = null;
+ CompletableFuture> response =
+ api.fetchCollectionTokenDetails(id, tokenId);
+ }
+
+ /**
+ * Get a collection by id
+ *
+ * Get a collection by id
+ *
+ * @throws ApiException if the Api call fails
+ */
+ @Test
+ public void getCollectionByIdTest() throws ApiException {
+ String id = null;
+ CompletableFuture> response = api.getCollectionById(id);
+ }
+
+ /**
+ * Get collections
+ *
+ * Get collections (paginated)
+ *
+ * @throws ApiException if the Api call fails
+ */
+ @Test
+ public void getLinkedCollectionsTest() throws ApiException {
+ String pageCursor = null;
+ BigDecimal pageSize = null;
+ Object status = null;
+ CompletableFuture> response =
+ api.getLinkedCollections(pageCursor, pageSize, status);
+ }
+
/**
* Return a linked token
*
@@ -80,11 +162,9 @@ public void issueNewTokenTest() throws ApiException {
}
/**
- * Link a token
+ * Link a contract
*
- * Link an already existing token (by assetId, collectionId or contractId as refId) to a
- * workspace across EVM, Stellar, or Ripple platforms. The token will be linked to the workspace
- * if it does not already exist.
+ *
Link an a contract
*
* @throws ApiException if the Api call fails
*/
@@ -96,6 +176,22 @@ public void linkTest() throws ApiException {
api.link(tokenLinkRequestDto, idempotencyKey);
}
+ /**
+ * Mint tokens
+ *
+ *
Mint tokens and upload metadata
+ *
+ * @throws ApiException if the Api call fails
+ */
+ @Test
+ public void mintCollectionTokenTest() throws ApiException {
+ CollectionMintRequestDto collectionMintRequestDto = null;
+ String id = null;
+ String idempotencyKey = null;
+ CompletableFuture> response =
+ api.mintCollectionToken(collectionMintRequestDto, id, idempotencyKey);
+ }
+
/**
* Unlink a token
*
@@ -110,4 +206,18 @@ public void unlinkTest() throws ApiException {
CompletableFuture> response = api.unlink(id);
}
+
+ /**
+ * Delete a collection link
+ *
+ * Delete a collection link
+ *
+ * @throws ApiException if the Api call fails
+ */
+ @Test
+ public void unlinkCollectionTest() throws ApiException {
+ String id = null;
+
+ CompletableFuture> response = api.unlinkCollection(id);
+ }
}
diff --git a/src/test/java/com/fireblocks/sdk/api/TransactionsApiTest.java b/src/test/java/com/fireblocks/sdk/api/TransactionsApiTest.java
index d516fa2..894b3fa 100644
--- a/src/test/java/com/fireblocks/sdk/api/TransactionsApiTest.java
+++ b/src/test/java/com/fireblocks/sdk/api/TransactionsApiTest.java
@@ -22,12 +22,14 @@
import com.fireblocks.sdk.model.EstimatedNetworkFeeResponse;
import com.fireblocks.sdk.model.EstimatedTransactionFeeResponse;
import com.fireblocks.sdk.model.FreezeTransactionResponse;
+import com.fireblocks.sdk.model.RescanTransaction;
import com.fireblocks.sdk.model.SetConfirmationsThresholdRequest;
import com.fireblocks.sdk.model.SetConfirmationsThresholdResponse;
import com.fireblocks.sdk.model.TransactionRequest;
import com.fireblocks.sdk.model.TransactionResponse;
import com.fireblocks.sdk.model.UnfreezeTransactionResponse;
import com.fireblocks.sdk.model.ValidateAddressResponse;
+import com.fireblocks.sdk.model.ValidatedTransactionsForRescan;
import java.util.List;
import java.util.UUID;
import java.util.concurrent.CompletableFuture;
@@ -205,6 +207,23 @@ public void getTransactionsTest() throws ApiException {
destWalletId);
}
+ /**
+ * rescan array of transactions
+ *
+ * rescan transaction by running an async job. </br> **Note**: - These endpoints are
+ * currently in beta and might be subject to changes. - We limit the amount of the transaction
+ * to 16 per request.
+ *
+ * @throws ApiException if the Api call fails
+ */
+ @Test
+ public void rescanTransactionsBetaTest() throws ApiException {
+ List rescanTransaction = null;
+ String idempotencyKey = null;
+ CompletableFuture>> response =
+ api.rescanTransactionsBeta(rescanTransaction, idempotencyKey);
+ }
+
/**
* Set confirmation threshold by transaction hash
*
diff --git a/src/test/java/com/fireblocks/sdk/model/AddAbiRequestDtoTest.java b/src/test/java/com/fireblocks/sdk/model/AddAbiRequestDtoTest.java
new file mode 100644
index 0000000..9ed3ebc
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/AddAbiRequestDtoTest.java
@@ -0,0 +1,51 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for AddAbiRequestDto */
+public class AddAbiRequestDtoTest {
+ private final AddAbiRequestDto model = new AddAbiRequestDto();
+
+ /** Model tests for AddAbiRequestDto */
+ @Test
+ public void testAddAbiRequestDto() {
+ // TODO: test AddAbiRequestDto
+ }
+
+ /** Test the property 'contractAddress' */
+ @Test
+ public void contractAddressTest() {
+ // TODO: test contractAddress
+ }
+
+ /** Test the property 'baseAssetId' */
+ @Test
+ public void baseAssetIdTest() {
+ // TODO: test baseAssetId
+ }
+
+ /** Test the property 'abi' */
+ @Test
+ public void abiTest() {
+ // TODO: test abi
+ }
+
+ /** Test the property 'name' */
+ @Test
+ public void nameTest() {
+ // TODO: test name
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/CollectionBurnRequestDtoTest.java b/src/test/java/com/fireblocks/sdk/model/CollectionBurnRequestDtoTest.java
new file mode 100644
index 0000000..e14c95c
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/CollectionBurnRequestDtoTest.java
@@ -0,0 +1,45 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for CollectionBurnRequestDto */
+public class CollectionBurnRequestDtoTest {
+ private final CollectionBurnRequestDto model = new CollectionBurnRequestDto();
+
+ /** Model tests for CollectionBurnRequestDto */
+ @Test
+ public void testCollectionBurnRequestDto() {
+ // TODO: test CollectionBurnRequestDto
+ }
+
+ /** Test the property 'vaultAccountId' */
+ @Test
+ public void vaultAccountIdTest() {
+ // TODO: test vaultAccountId
+ }
+
+ /** Test the property 'tokenId' */
+ @Test
+ public void tokenIdTest() {
+ // TODO: test tokenId
+ }
+
+ /** Test the property 'amount' */
+ @Test
+ public void amountTest() {
+ // TODO: test amount
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/CollectionBurnResponseDtoTest.java b/src/test/java/com/fireblocks/sdk/model/CollectionBurnResponseDtoTest.java
new file mode 100644
index 0000000..b52fb64
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/CollectionBurnResponseDtoTest.java
@@ -0,0 +1,33 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for CollectionBurnResponseDto */
+public class CollectionBurnResponseDtoTest {
+ private final CollectionBurnResponseDto model = new CollectionBurnResponseDto();
+
+ /** Model tests for CollectionBurnResponseDto */
+ @Test
+ public void testCollectionBurnResponseDto() {
+ // TODO: test CollectionBurnResponseDto
+ }
+
+ /** Test the property 'txId' */
+ @Test
+ public void txIdTest() {
+ // TODO: test txId
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/CollectionDeployRequestDtoTest.java b/src/test/java/com/fireblocks/sdk/model/CollectionDeployRequestDtoTest.java
new file mode 100644
index 0000000..c68a77e
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/CollectionDeployRequestDtoTest.java
@@ -0,0 +1,69 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for CollectionDeployRequestDto */
+public class CollectionDeployRequestDtoTest {
+ private final CollectionDeployRequestDto model = new CollectionDeployRequestDto();
+
+ /** Model tests for CollectionDeployRequestDto */
+ @Test
+ public void testCollectionDeployRequestDto() {
+ // TODO: test CollectionDeployRequestDto
+ }
+
+ /** Test the property 'baseAssetId' */
+ @Test
+ public void baseAssetIdTest() {
+ // TODO: test baseAssetId
+ }
+
+ /** Test the property 'vaultAccountId' */
+ @Test
+ public void vaultAccountIdTest() {
+ // TODO: test vaultAccountId
+ }
+
+ /** Test the property 'type' */
+ @Test
+ public void typeTest() {
+ // TODO: test type
+ }
+
+ /** Test the property 'name' */
+ @Test
+ public void nameTest() {
+ // TODO: test name
+ }
+
+ /** Test the property 'symbol' */
+ @Test
+ public void symbolTest() {
+ // TODO: test symbol
+ }
+
+ /** Test the property 'adminAddress' */
+ @Test
+ public void adminAddressTest() {
+ // TODO: test adminAddress
+ }
+
+ /** Test the property 'displayName' */
+ @Test
+ public void displayNameTest() {
+ // TODO: test displayName
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/CollectionLinkDtoTest.java b/src/test/java/com/fireblocks/sdk/model/CollectionLinkDtoTest.java
new file mode 100644
index 0000000..75667e7
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/CollectionLinkDtoTest.java
@@ -0,0 +1,57 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for CollectionLinkDto */
+public class CollectionLinkDtoTest {
+ private final CollectionLinkDto model = new CollectionLinkDto();
+
+ /** Model tests for CollectionLinkDto */
+ @Test
+ public void testCollectionLinkDto() {
+ // TODO: test CollectionLinkDto
+ }
+
+ /** Test the property 'id' */
+ @Test
+ public void idTest() {
+ // TODO: test id
+ }
+
+ /** Test the property 'status' */
+ @Test
+ public void statusTest() {
+ // TODO: test status
+ }
+
+ /** Test the property 'type' */
+ @Test
+ public void typeTest() {
+ // TODO: test type
+ }
+
+ /** Test the property 'displayName' */
+ @Test
+ public void displayNameTest() {
+ // TODO: test displayName
+ }
+
+ /** Test the property 'collectionMetadata' */
+ @Test
+ public void collectionMetadataTest() {
+ // TODO: test collectionMetadata
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/CollectionMintRequestDtoTest.java b/src/test/java/com/fireblocks/sdk/model/CollectionMintRequestDtoTest.java
new file mode 100644
index 0000000..0cbf24b
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/CollectionMintRequestDtoTest.java
@@ -0,0 +1,63 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for CollectionMintRequestDto */
+public class CollectionMintRequestDtoTest {
+ private final CollectionMintRequestDto model = new CollectionMintRequestDto();
+
+ /** Model tests for CollectionMintRequestDto */
+ @Test
+ public void testCollectionMintRequestDto() {
+ // TODO: test CollectionMintRequestDto
+ }
+
+ /** Test the property 'vaultAccountId' */
+ @Test
+ public void vaultAccountIdTest() {
+ // TODO: test vaultAccountId
+ }
+
+ /** Test the property 'to' */
+ @Test
+ public void toTest() {
+ // TODO: test to
+ }
+
+ /** Test the property 'tokenId' */
+ @Test
+ public void tokenIdTest() {
+ // TODO: test tokenId
+ }
+
+ /** Test the property 'amount' */
+ @Test
+ public void amountTest() {
+ // TODO: test amount
+ }
+
+ /** Test the property 'metadataURI' */
+ @Test
+ public void metadataURITest() {
+ // TODO: test metadataURI
+ }
+
+ /** Test the property 'metadata' */
+ @Test
+ public void metadataTest() {
+ // TODO: test metadata
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/CollectionMintResponseDtoTest.java b/src/test/java/com/fireblocks/sdk/model/CollectionMintResponseDtoTest.java
new file mode 100644
index 0000000..39dc24c
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/CollectionMintResponseDtoTest.java
@@ -0,0 +1,33 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for CollectionMintResponseDto */
+public class CollectionMintResponseDtoTest {
+ private final CollectionMintResponseDto model = new CollectionMintResponseDto();
+
+ /** Model tests for CollectionMintResponseDto */
+ @Test
+ public void testCollectionMintResponseDto() {
+ // TODO: test CollectionMintResponseDto
+ }
+
+ /** Test the property 'txId' */
+ @Test
+ public void txIdTest() {
+ // TODO: test txId
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/CollectionTokenMetadataAttributeDtoTest.java b/src/test/java/com/fireblocks/sdk/model/CollectionTokenMetadataAttributeDtoTest.java
new file mode 100644
index 0000000..df0237a
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/CollectionTokenMetadataAttributeDtoTest.java
@@ -0,0 +1,46 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for CollectionTokenMetadataAttributeDto */
+public class CollectionTokenMetadataAttributeDtoTest {
+ private final CollectionTokenMetadataAttributeDto model =
+ new CollectionTokenMetadataAttributeDto();
+
+ /** Model tests for CollectionTokenMetadataAttributeDto */
+ @Test
+ public void testCollectionTokenMetadataAttributeDto() {
+ // TODO: test CollectionTokenMetadataAttributeDto
+ }
+
+ /** Test the property 'traitType' */
+ @Test
+ public void traitTypeTest() {
+ // TODO: test traitType
+ }
+
+ /** Test the property 'value' */
+ @Test
+ public void valueTest() {
+ // TODO: test value
+ }
+
+ /** Test the property 'displayType' */
+ @Test
+ public void displayTypeTest() {
+ // TODO: test displayType
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/CollectionTokenMetadataDtoTest.java b/src/test/java/com/fireblocks/sdk/model/CollectionTokenMetadataDtoTest.java
new file mode 100644
index 0000000..a53a9b1
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/CollectionTokenMetadataDtoTest.java
@@ -0,0 +1,63 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for CollectionTokenMetadataDto */
+public class CollectionTokenMetadataDtoTest {
+ private final CollectionTokenMetadataDto model = new CollectionTokenMetadataDto();
+
+ /** Model tests for CollectionTokenMetadataDto */
+ @Test
+ public void testCollectionTokenMetadataDto() {
+ // TODO: test CollectionTokenMetadataDto
+ }
+
+ /** Test the property 'name' */
+ @Test
+ public void nameTest() {
+ // TODO: test name
+ }
+
+ /** Test the property 'description' */
+ @Test
+ public void descriptionTest() {
+ // TODO: test description
+ }
+
+ /** Test the property 'image' */
+ @Test
+ public void imageTest() {
+ // TODO: test image
+ }
+
+ /** Test the property 'animationUrl' */
+ @Test
+ public void animationUrlTest() {
+ // TODO: test animationUrl
+ }
+
+ /** Test the property 'externalUrl' */
+ @Test
+ public void externalUrlTest() {
+ // TODO: test externalUrl
+ }
+
+ /** Test the property 'attributes' */
+ @Test
+ public void attributesTest() {
+ // TODO: test attributes
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/CollectionTypeTest.java b/src/test/java/com/fireblocks/sdk/model/CollectionTypeTest.java
new file mode 100644
index 0000000..67908f1
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/CollectionTypeTest.java
@@ -0,0 +1,25 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for CollectionType */
+public class CollectionTypeTest {
+ /** Model tests for CollectionType */
+ @Test
+ public void testCollectionType() {
+ // TODO: test CollectionType
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/ContractWithAbiDtoTest.java b/src/test/java/com/fireblocks/sdk/model/ContractWithAbiDtoTest.java
new file mode 100644
index 0000000..cdfc9f6
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/ContractWithAbiDtoTest.java
@@ -0,0 +1,69 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for ContractWithAbiDto */
+public class ContractWithAbiDtoTest {
+ private final ContractWithAbiDto model = new ContractWithAbiDto();
+
+ /** Model tests for ContractWithAbiDto */
+ @Test
+ public void testContractWithAbiDto() {
+ // TODO: test ContractWithAbiDto
+ }
+
+ /** Test the property 'contractAddress' */
+ @Test
+ public void contractAddressTest() {
+ // TODO: test contractAddress
+ }
+
+ /** Test the property 'baseAssetId' */
+ @Test
+ public void baseAssetIdTest() {
+ // TODO: test baseAssetId
+ }
+
+ /** Test the property 'name' */
+ @Test
+ public void nameTest() {
+ // TODO: test name
+ }
+
+ /** Test the property 'abi' */
+ @Test
+ public void abiTest() {
+ // TODO: test abi
+ }
+
+ /** Test the property 'isProxy' */
+ @Test
+ public void isProxyTest() {
+ // TODO: test isProxy
+ }
+
+ /** Test the property 'implementation' */
+ @Test
+ public void implementationTest() {
+ // TODO: test implementation
+ }
+
+ /** Test the property 'isPublic' */
+ @Test
+ public void isPublicTest() {
+ // TODO: test isPublic
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/CreateSigningKeyDtoTest.java b/src/test/java/com/fireblocks/sdk/model/CreateSigningKeyDtoTest.java
index 9e03960..dfa752a 100644
--- a/src/test/java/com/fireblocks/sdk/model/CreateSigningKeyDtoTest.java
+++ b/src/test/java/com/fireblocks/sdk/model/CreateSigningKeyDtoTest.java
@@ -42,4 +42,10 @@ public void signedCertPemTest() {
public void agentUserIdTest() {
// TODO: test agentUserId
}
+
+ /** Test the property 'proofOfOwnership' */
+ @Test
+ public void proofOfOwnershipTest() {
+ // TODO: test proofOfOwnership
+ }
}
diff --git a/src/test/java/com/fireblocks/sdk/model/CreateVaultAccountRequestTest.java b/src/test/java/com/fireblocks/sdk/model/CreateVaultAccountRequestTest.java
index a74aacb..cf290d3 100644
--- a/src/test/java/com/fireblocks/sdk/model/CreateVaultAccountRequestTest.java
+++ b/src/test/java/com/fireblocks/sdk/model/CreateVaultAccountRequestTest.java
@@ -48,4 +48,16 @@ public void customerRefIdTest() {
public void autoFuelTest() {
// TODO: test autoFuel
}
+
+ /** Test the property 'vaultType' */
+ @Test
+ public void vaultTypeTest() {
+ // TODO: test vaultType
+ }
+
+ /** Test the property 'autoAssign' */
+ @Test
+ public void autoAssignTest() {
+ // TODO: test autoAssign
+ }
}
diff --git a/src/test/java/com/fireblocks/sdk/model/ExchangeAssetTest.java b/src/test/java/com/fireblocks/sdk/model/ExchangeAssetTest.java
index af9d823..5344f72 100644
--- a/src/test/java/com/fireblocks/sdk/model/ExchangeAssetTest.java
+++ b/src/test/java/com/fireblocks/sdk/model/ExchangeAssetTest.java
@@ -54,4 +54,10 @@ public void totalTest() {
public void availableTest() {
// TODO: test available
}
+
+ /** Test the property 'credit' */
+ @Test
+ public void creditTest() {
+ // TODO: test credit
+ }
}
diff --git a/src/test/java/com/fireblocks/sdk/model/FetchAbiRequestDtoTest.java b/src/test/java/com/fireblocks/sdk/model/FetchAbiRequestDtoTest.java
new file mode 100644
index 0000000..5183723
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/FetchAbiRequestDtoTest.java
@@ -0,0 +1,39 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for FetchAbiRequestDto */
+public class FetchAbiRequestDtoTest {
+ private final FetchAbiRequestDto model = new FetchAbiRequestDto();
+
+ /** Model tests for FetchAbiRequestDto */
+ @Test
+ public void testFetchAbiRequestDto() {
+ // TODO: test FetchAbiRequestDto
+ }
+
+ /** Test the property 'baseAssetId' */
+ @Test
+ public void baseAssetIdTest() {
+ // TODO: test baseAssetId
+ }
+
+ /** Test the property 'contractAddress' */
+ @Test
+ public void contractAddressTest() {
+ // TODO: test contractAddress
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/RescanTransactionTest.java b/src/test/java/com/fireblocks/sdk/model/RescanTransactionTest.java
new file mode 100644
index 0000000..f097080
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/RescanTransactionTest.java
@@ -0,0 +1,39 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for RescanTransaction */
+public class RescanTransactionTest {
+ private final RescanTransaction model = new RescanTransaction();
+
+ /** Model tests for RescanTransaction */
+ @Test
+ public void testRescanTransaction() {
+ // TODO: test RescanTransaction
+ }
+
+ /** Test the property 'txHash' */
+ @Test
+ public void txHashTest() {
+ // TODO: test txHash
+ }
+
+ /** Test the property 'assetId' */
+ @Test
+ public void assetIdTest() {
+ // TODO: test assetId
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/TokenLinkRequestDtoTest.java b/src/test/java/com/fireblocks/sdk/model/TokenLinkRequestDtoTest.java
index 465a4ad..9445f09 100644
--- a/src/test/java/com/fireblocks/sdk/model/TokenLinkRequestDtoTest.java
+++ b/src/test/java/com/fireblocks/sdk/model/TokenLinkRequestDtoTest.java
@@ -42,4 +42,16 @@ public void refIdTest() {
public void displayNameTest() {
// TODO: test displayName
}
+
+ /** Test the property 'baseAssetId' */
+ @Test
+ public void baseAssetIdTest() {
+ // TODO: test baseAssetId
+ }
+
+ /** Test the property 'contractAddress' */
+ @Test
+ public void contractAddressTest() {
+ // TODO: test contractAddress
+ }
}
diff --git a/src/test/java/com/fireblocks/sdk/model/TransactionRequestTest.java b/src/test/java/com/fireblocks/sdk/model/TransactionRequestTest.java
index 5653bdd..0139b4b 100644
--- a/src/test/java/com/fireblocks/sdk/model/TransactionRequestTest.java
+++ b/src/test/java/com/fireblocks/sdk/model/TransactionRequestTest.java
@@ -115,6 +115,12 @@ public void maxFeeTest() {
// TODO: test maxFee
}
+ /** Test the property 'maxTotalFee' */
+ @Test
+ public void maxTotalFeeTest() {
+ // TODO: test maxTotalFee
+ }
+
/** Test the property 'gasLimit' */
@Test
public void gasLimitTest() {
@@ -174,4 +180,10 @@ public void networkStakingTest() {
public void cpuStakingTest() {
// TODO: test cpuStaking
}
+
+ /** Test the property 'useGasless' */
+ @Test
+ public void useGaslessTest() {
+ // TODO: test useGasless
+ }
}
diff --git a/src/test/java/com/fireblocks/sdk/model/TravelRuleCreateTransactionRequestTest.java b/src/test/java/com/fireblocks/sdk/model/TravelRuleCreateTransactionRequestTest.java
index 817d12b..32aba36 100644
--- a/src/test/java/com/fireblocks/sdk/model/TravelRuleCreateTransactionRequestTest.java
+++ b/src/test/java/com/fireblocks/sdk/model/TravelRuleCreateTransactionRequestTest.java
@@ -38,6 +38,12 @@ public void beneficiaryVASPdidTest() {
// TODO: test beneficiaryVASPdid
}
+ /** Test the property 'originatorVASPname' */
+ @Test
+ public void originatorVASPnameTest() {
+ // TODO: test originatorVASPname
+ }
+
/** Test the property 'beneficiaryVASPname' */
@Test
public void beneficiaryVASPnameTest() {
@@ -86,6 +92,24 @@ public void travelRuleBehaviorTest() {
// TODO: test travelRuleBehavior
}
+ /** Test the property 'originatorRef' */
+ @Test
+ public void originatorRefTest() {
+ // TODO: test originatorRef
+ }
+
+ /** Test the property 'beneficiaryRef' */
+ @Test
+ public void beneficiaryRefTest() {
+ // TODO: test beneficiaryRef
+ }
+
+ /** Test the property 'travelRuleBehaviorRef' */
+ @Test
+ public void travelRuleBehaviorRefTest() {
+ // TODO: test travelRuleBehaviorRef
+ }
+
/** Test the property 'originatorProof' */
@Test
public void originatorProofTest() {
@@ -98,9 +122,21 @@ public void beneficiaryProofTest() {
// TODO: test beneficiaryProof
}
- /** Test the property 'pii' */
+ /** Test the property 'beneficiaryDid' */
+ @Test
+ public void beneficiaryDidTest() {
+ // TODO: test beneficiaryDid
+ }
+
+ /** Test the property 'originatorDid' */
+ @Test
+ public void originatorDidTest() {
+ // TODO: test originatorDid
+ }
+
+ /** Test the property 'isNonCustodial' */
@Test
- public void piiTest() {
- // TODO: test pii
+ public void isNonCustodialTest() {
+ // TODO: test isNonCustodial
}
}
diff --git a/src/test/java/com/fireblocks/sdk/model/TravelRuleDateAndPlaceOfBirthTest.java b/src/test/java/com/fireblocks/sdk/model/TravelRuleDateAndPlaceOfBirthTest.java
new file mode 100644
index 0000000..79e7efe
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/TravelRuleDateAndPlaceOfBirthTest.java
@@ -0,0 +1,39 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for TravelRuleDateAndPlaceOfBirth */
+public class TravelRuleDateAndPlaceOfBirthTest {
+ private final TravelRuleDateAndPlaceOfBirth model = new TravelRuleDateAndPlaceOfBirth();
+
+ /** Model tests for TravelRuleDateAndPlaceOfBirth */
+ @Test
+ public void testTravelRuleDateAndPlaceOfBirth() {
+ // TODO: test TravelRuleDateAndPlaceOfBirth
+ }
+
+ /** Test the property 'dateOfBirth' */
+ @Test
+ public void dateOfBirthTest() {
+ // TODO: test dateOfBirth
+ }
+
+ /** Test the property 'placeOfBirth' */
+ @Test
+ public void placeOfBirthTest() {
+ // TODO: test placeOfBirth
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/TravelRuleGeographicAddressTest.java b/src/test/java/com/fireblocks/sdk/model/TravelRuleGeographicAddressTest.java
new file mode 100644
index 0000000..1b046ae
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/TravelRuleGeographicAddressTest.java
@@ -0,0 +1,123 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for TravelRuleGeographicAddress */
+public class TravelRuleGeographicAddressTest {
+ private final TravelRuleGeographicAddress model = new TravelRuleGeographicAddress();
+
+ /** Model tests for TravelRuleGeographicAddress */
+ @Test
+ public void testTravelRuleGeographicAddress() {
+ // TODO: test TravelRuleGeographicAddress
+ }
+
+ /** Test the property 'streetName' */
+ @Test
+ public void streetNameTest() {
+ // TODO: test streetName
+ }
+
+ /** Test the property 'townName' */
+ @Test
+ public void townNameTest() {
+ // TODO: test townName
+ }
+
+ /** Test the property 'country' */
+ @Test
+ public void countryTest() {
+ // TODO: test country
+ }
+
+ /** Test the property 'buildingNumber' */
+ @Test
+ public void buildingNumberTest() {
+ // TODO: test buildingNumber
+ }
+
+ /** Test the property 'postCode' */
+ @Test
+ public void postCodeTest() {
+ // TODO: test postCode
+ }
+
+ /** Test the property 'addressType' */
+ @Test
+ public void addressTypeTest() {
+ // TODO: test addressType
+ }
+
+ /** Test the property 'department' */
+ @Test
+ public void departmentTest() {
+ // TODO: test department
+ }
+
+ /** Test the property 'subDepartment' */
+ @Test
+ public void subDepartmentTest() {
+ // TODO: test subDepartment
+ }
+
+ /** Test the property 'buildingName' */
+ @Test
+ public void buildingNameTest() {
+ // TODO: test buildingName
+ }
+
+ /** Test the property 'floor' */
+ @Test
+ public void floorTest() {
+ // TODO: test floor
+ }
+
+ /** Test the property 'postBox' */
+ @Test
+ public void postBoxTest() {
+ // TODO: test postBox
+ }
+
+ /** Test the property 'room' */
+ @Test
+ public void roomTest() {
+ // TODO: test room
+ }
+
+ /** Test the property 'townLocationName' */
+ @Test
+ public void townLocationNameTest() {
+ // TODO: test townLocationName
+ }
+
+ /** Test the property 'districtName' */
+ @Test
+ public void districtNameTest() {
+ // TODO: test districtName
+ }
+
+ /** Test the property 'countrySubDivision' */
+ @Test
+ public void countrySubDivisionTest() {
+ // TODO: test countrySubDivision
+ }
+
+ /** Test the property 'addressLine' */
+ @Test
+ public void addressLineTest() {
+ // TODO: test addressLine
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/TravelRuleLegalNameIdentifiersTest.java b/src/test/java/com/fireblocks/sdk/model/TravelRuleLegalNameIdentifiersTest.java
new file mode 100644
index 0000000..39eeedc
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/TravelRuleLegalNameIdentifiersTest.java
@@ -0,0 +1,39 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for TravelRuleLegalNameIdentifiers */
+public class TravelRuleLegalNameIdentifiersTest {
+ private final TravelRuleLegalNameIdentifiers model = new TravelRuleLegalNameIdentifiers();
+
+ /** Model tests for TravelRuleLegalNameIdentifiers */
+ @Test
+ public void testTravelRuleLegalNameIdentifiers() {
+ // TODO: test TravelRuleLegalNameIdentifiers
+ }
+
+ /** Test the property 'legalPersonNameIdentifierType' */
+ @Test
+ public void legalPersonNameIdentifierTypeTest() {
+ // TODO: test legalPersonNameIdentifierType
+ }
+
+ /** Test the property 'legalPersonName' */
+ @Test
+ public void legalPersonNameTest() {
+ // TODO: test legalPersonName
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/TravelRuleLegalPersonNameIdentifierTest.java b/src/test/java/com/fireblocks/sdk/model/TravelRuleLegalPersonNameIdentifierTest.java
new file mode 100644
index 0000000..2a52c84
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/TravelRuleLegalPersonNameIdentifierTest.java
@@ -0,0 +1,46 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for TravelRuleLegalPersonNameIdentifier */
+public class TravelRuleLegalPersonNameIdentifierTest {
+ private final TravelRuleLegalPersonNameIdentifier model =
+ new TravelRuleLegalPersonNameIdentifier();
+
+ /** Model tests for TravelRuleLegalPersonNameIdentifier */
+ @Test
+ public void testTravelRuleLegalPersonNameIdentifier() {
+ // TODO: test TravelRuleLegalPersonNameIdentifier
+ }
+
+ /** Test the property 'nameIdentifier' */
+ @Test
+ public void nameIdentifierTest() {
+ // TODO: test nameIdentifier
+ }
+
+ /** Test the property 'localNameIdentifier' */
+ @Test
+ public void localNameIdentifierTest() {
+ // TODO: test localNameIdentifier
+ }
+
+ /** Test the property 'phoneticNameIdentifier' */
+ @Test
+ public void phoneticNameIdentifierTest() {
+ // TODO: test phoneticNameIdentifier
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/TravelRuleLegalPersonTest.java b/src/test/java/com/fireblocks/sdk/model/TravelRuleLegalPersonTest.java
new file mode 100644
index 0000000..d482990
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/TravelRuleLegalPersonTest.java
@@ -0,0 +1,63 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for TravelRuleLegalPerson */
+public class TravelRuleLegalPersonTest {
+ private final TravelRuleLegalPerson model = new TravelRuleLegalPerson();
+
+ /** Model tests for TravelRuleLegalPerson */
+ @Test
+ public void testTravelRuleLegalPerson() {
+ // TODO: test TravelRuleLegalPerson
+ }
+
+ /** Test the property 'name' */
+ @Test
+ public void nameTest() {
+ // TODO: test name
+ }
+
+ /** Test the property 'geographicAddress' */
+ @Test
+ public void geographicAddressTest() {
+ // TODO: test geographicAddress
+ }
+
+ /** Test the property 'nationalIdentification' */
+ @Test
+ public void nationalIdentificationTest() {
+ // TODO: test nationalIdentification
+ }
+
+ /** Test the property 'customerIdentification' */
+ @Test
+ public void customerIdentificationTest() {
+ // TODO: test customerIdentification
+ }
+
+ /** Test the property 'customerNumber' */
+ @Test
+ public void customerNumberTest() {
+ // TODO: test customerNumber
+ }
+
+ /** Test the property 'countryOfRegistration' */
+ @Test
+ public void countryOfRegistrationTest() {
+ // TODO: test countryOfRegistration
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/TravelRuleNationalIdentificationTest.java b/src/test/java/com/fireblocks/sdk/model/TravelRuleNationalIdentificationTest.java
new file mode 100644
index 0000000..62884e0
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/TravelRuleNationalIdentificationTest.java
@@ -0,0 +1,51 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for TravelRuleNationalIdentification */
+public class TravelRuleNationalIdentificationTest {
+ private final TravelRuleNationalIdentification model = new TravelRuleNationalIdentification();
+
+ /** Model tests for TravelRuleNationalIdentification */
+ @Test
+ public void testTravelRuleNationalIdentification() {
+ // TODO: test TravelRuleNationalIdentification
+ }
+
+ /** Test the property 'countryOfIssue' */
+ @Test
+ public void countryOfIssueTest() {
+ // TODO: test countryOfIssue
+ }
+
+ /** Test the property 'nationalIdentifier' */
+ @Test
+ public void nationalIdentifierTest() {
+ // TODO: test nationalIdentifier
+ }
+
+ /** Test the property 'nationalIdentifierType' */
+ @Test
+ public void nationalIdentifierTypeTest() {
+ // TODO: test nationalIdentifierType
+ }
+
+ /** Test the property 'registrationAuthority' */
+ @Test
+ public void registrationAuthorityTest() {
+ // TODO: test registrationAuthority
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/TravelRuleNaturalNameIdentifierTest.java b/src/test/java/com/fireblocks/sdk/model/TravelRuleNaturalNameIdentifierTest.java
new file mode 100644
index 0000000..ce57ac4
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/TravelRuleNaturalNameIdentifierTest.java
@@ -0,0 +1,45 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for TravelRuleNaturalNameIdentifier */
+public class TravelRuleNaturalNameIdentifierTest {
+ private final TravelRuleNaturalNameIdentifier model = new TravelRuleNaturalNameIdentifier();
+
+ /** Model tests for TravelRuleNaturalNameIdentifier */
+ @Test
+ public void testTravelRuleNaturalNameIdentifier() {
+ // TODO: test TravelRuleNaturalNameIdentifier
+ }
+
+ /** Test the property 'primaryIdentifier' */
+ @Test
+ public void primaryIdentifierTest() {
+ // TODO: test primaryIdentifier
+ }
+
+ /** Test the property 'secondaryIdentifier' */
+ @Test
+ public void secondaryIdentifierTest() {
+ // TODO: test secondaryIdentifier
+ }
+
+ /** Test the property 'nameIdentifierType' */
+ @Test
+ public void nameIdentifierTypeTest() {
+ // TODO: test nameIdentifierType
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/TravelRuleNaturalNameIdentifiersTest.java b/src/test/java/com/fireblocks/sdk/model/TravelRuleNaturalNameIdentifiersTest.java
new file mode 100644
index 0000000..da76234
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/TravelRuleNaturalNameIdentifiersTest.java
@@ -0,0 +1,45 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for TravelRuleNaturalNameIdentifiers */
+public class TravelRuleNaturalNameIdentifiersTest {
+ private final TravelRuleNaturalNameIdentifiers model = new TravelRuleNaturalNameIdentifiers();
+
+ /** Model tests for TravelRuleNaturalNameIdentifiers */
+ @Test
+ public void testTravelRuleNaturalNameIdentifiers() {
+ // TODO: test TravelRuleNaturalNameIdentifiers
+ }
+
+ /** Test the property 'primaryIdentifier' */
+ @Test
+ public void primaryIdentifierTest() {
+ // TODO: test primaryIdentifier
+ }
+
+ /** Test the property 'secondaryIdentifier' */
+ @Test
+ public void secondaryIdentifierTest() {
+ // TODO: test secondaryIdentifier
+ }
+
+ /** Test the property 'nameIdentifierType' */
+ @Test
+ public void nameIdentifierTypeTest() {
+ // TODO: test nameIdentifierType
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/TravelRuleNaturalPersonNameIdentifierTest.java b/src/test/java/com/fireblocks/sdk/model/TravelRuleNaturalPersonNameIdentifierTest.java
new file mode 100644
index 0000000..f5f5eb5
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/TravelRuleNaturalPersonNameIdentifierTest.java
@@ -0,0 +1,46 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for TravelRuleNaturalPersonNameIdentifier */
+public class TravelRuleNaturalPersonNameIdentifierTest {
+ private final TravelRuleNaturalPersonNameIdentifier model =
+ new TravelRuleNaturalPersonNameIdentifier();
+
+ /** Model tests for TravelRuleNaturalPersonNameIdentifier */
+ @Test
+ public void testTravelRuleNaturalPersonNameIdentifier() {
+ // TODO: test TravelRuleNaturalPersonNameIdentifier
+ }
+
+ /** Test the property 'nameIdentifier' */
+ @Test
+ public void nameIdentifierTest() {
+ // TODO: test nameIdentifier
+ }
+
+ /** Test the property 'localNameIdentifier' */
+ @Test
+ public void localNameIdentifierTest() {
+ // TODO: test localNameIdentifier
+ }
+
+ /** Test the property 'phoneticNameIdentifier' */
+ @Test
+ public void phoneticNameIdentifierTest() {
+ // TODO: test phoneticNameIdentifier
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/TravelRuleNaturalPersonTest.java b/src/test/java/com/fireblocks/sdk/model/TravelRuleNaturalPersonTest.java
new file mode 100644
index 0000000..d26199d
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/TravelRuleNaturalPersonTest.java
@@ -0,0 +1,75 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for TravelRuleNaturalPerson */
+public class TravelRuleNaturalPersonTest {
+ private final TravelRuleNaturalPerson model = new TravelRuleNaturalPerson();
+
+ /** Model tests for TravelRuleNaturalPerson */
+ @Test
+ public void testTravelRuleNaturalPerson() {
+ // TODO: test TravelRuleNaturalPerson
+ }
+
+ /** Test the property 'name' */
+ @Test
+ public void nameTest() {
+ // TODO: test name
+ }
+
+ /** Test the property 'geographicAddress' */
+ @Test
+ public void geographicAddressTest() {
+ // TODO: test geographicAddress
+ }
+
+ /** Test the property 'nationalIdentification' */
+ @Test
+ public void nationalIdentificationTest() {
+ // TODO: test nationalIdentification
+ }
+
+ /** Test the property 'dateAndPlaceOfBirth' */
+ @Test
+ public void dateAndPlaceOfBirthTest() {
+ // TODO: test dateAndPlaceOfBirth
+ }
+
+ /** Test the property 'customerIdentification' */
+ @Test
+ public void customerIdentificationTest() {
+ // TODO: test customerIdentification
+ }
+
+ /** Test the property 'countryOfResidence' */
+ @Test
+ public void countryOfResidenceTest() {
+ // TODO: test countryOfResidence
+ }
+
+ /** Test the property 'customerNumber' */
+ @Test
+ public void customerNumberTest() {
+ // TODO: test customerNumber
+ }
+
+ /** Test the property 'countryOfRegistration' */
+ @Test
+ public void countryOfRegistrationTest() {
+ // TODO: test countryOfRegistration
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/TravelRulePersonTest.java b/src/test/java/com/fireblocks/sdk/model/TravelRulePersonTest.java
new file mode 100644
index 0000000..fcdb728
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/TravelRulePersonTest.java
@@ -0,0 +1,39 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for TravelRulePerson */
+public class TravelRulePersonTest {
+ private final TravelRulePerson model = new TravelRulePerson();
+
+ /** Model tests for TravelRulePerson */
+ @Test
+ public void testTravelRulePerson() {
+ // TODO: test TravelRulePerson
+ }
+
+ /** Test the property 'naturalPerson' */
+ @Test
+ public void naturalPersonTest() {
+ // TODO: test naturalPerson
+ }
+
+ /** Test the property 'legalPerson' */
+ @Test
+ public void legalPersonTest() {
+ // TODO: test legalPerson
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/TravelRulePersonsTest.java b/src/test/java/com/fireblocks/sdk/model/TravelRulePersonsTest.java
new file mode 100644
index 0000000..67cdbc6
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/TravelRulePersonsTest.java
@@ -0,0 +1,39 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for TravelRulePersons */
+public class TravelRulePersonsTest {
+ private final TravelRulePersons model = new TravelRulePersons();
+
+ /** Model tests for TravelRulePersons */
+ @Test
+ public void testTravelRulePersons() {
+ // TODO: test TravelRulePersons
+ }
+
+ /** Test the property 'naturalPerson' */
+ @Test
+ public void naturalPersonTest() {
+ // TODO: test naturalPerson
+ }
+
+ /** Test the property 'legalPerson' */
+ @Test
+ public void legalPersonTest() {
+ // TODO: test legalPerson
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/TravelRulePiiIVMSTest.java b/src/test/java/com/fireblocks/sdk/model/TravelRulePiiIVMSTest.java
index d37c93a..016e33a 100644
--- a/src/test/java/com/fireblocks/sdk/model/TravelRulePiiIVMSTest.java
+++ b/src/test/java/com/fireblocks/sdk/model/TravelRulePiiIVMSTest.java
@@ -25,57 +25,21 @@ public void testTravelRulePiiIVMS() {
// TODO: test TravelRulePiiIVMS
}
- /** Test the property 'fullName' */
+ /** Test the property 'originatorPersons' */
@Test
- public void fullNameTest() {
- // TODO: test fullName
+ public void originatorPersonsTest() {
+ // TODO: test originatorPersons
}
- /** Test the property 'dateOfBirth' */
+ /** Test the property 'beneficiaryPersons' */
@Test
- public void dateOfBirthTest() {
- // TODO: test dateOfBirth
+ public void beneficiaryPersonsTest() {
+ // TODO: test beneficiaryPersons
}
- /** Test the property 'placeOfBirth' */
+ /** Test the property 'accountNumber' */
@Test
- public void placeOfBirthTest() {
- // TODO: test placeOfBirth
- }
-
- /** Test the property 'address' */
- @Test
- public void addressTest() {
- // TODO: test address
- }
-
- /** Test the property 'identificationNumber' */
- @Test
- public void identificationNumberTest() {
- // TODO: test identificationNumber
- }
-
- /** Test the property 'nationality' */
- @Test
- public void nationalityTest() {
- // TODO: test nationality
- }
-
- /** Test the property 'countryOfResidence' */
- @Test
- public void countryOfResidenceTest() {
- // TODO: test countryOfResidence
- }
-
- /** Test the property 'taxIdentificationNumber' */
- @Test
- public void taxIdentificationNumberTest() {
- // TODO: test taxIdentificationNumber
- }
-
- /** Test the property 'customerNumber' */
- @Test
- public void customerNumberTest() {
- // TODO: test customerNumber
+ public void accountNumberTest() {
+ // TODO: test accountNumber
}
}
diff --git a/src/test/java/com/fireblocks/sdk/model/TravelRuleValidateFullTransactionRequestTest.java b/src/test/java/com/fireblocks/sdk/model/TravelRuleValidateFullTransactionRequestTest.java
index 8e7a064..bad400d 100644
--- a/src/test/java/com/fireblocks/sdk/model/TravelRuleValidateFullTransactionRequestTest.java
+++ b/src/test/java/com/fireblocks/sdk/model/TravelRuleValidateFullTransactionRequestTest.java
@@ -127,10 +127,4 @@ public void originatorProofTest() {
public void beneficiaryProofTest() {
// TODO: test beneficiaryProof
}
-
- /** Test the property 'pii' */
- @Test
- public void piiTest() {
- // TODO: test pii
- }
}
diff --git a/src/test/java/com/fireblocks/sdk/model/ValidatedTransactionsForRescanTest.java b/src/test/java/com/fireblocks/sdk/model/ValidatedTransactionsForRescanTest.java
new file mode 100644
index 0000000..682d671
--- /dev/null
+++ b/src/test/java/com/fireblocks/sdk/model/ValidatedTransactionsForRescanTest.java
@@ -0,0 +1,45 @@
+/*
+ * Fireblocks API
+ * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
+ *
+ * The version of the OpenAPI document: 1.6.2
+ * Contact: support@fireblocks.com
+ *
+ * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
+ * https://openapi-generator.tech
+ * Do not edit the class manually.
+ */
+
+package com.fireblocks.sdk.model;
+
+
+import org.junit.Test;
+
+/** Model tests for ValidatedTransactionsForRescan */
+public class ValidatedTransactionsForRescanTest {
+ private final ValidatedTransactionsForRescan model = new ValidatedTransactionsForRescan();
+
+ /** Model tests for ValidatedTransactionsForRescan */
+ @Test
+ public void testValidatedTransactionsForRescan() {
+ // TODO: test ValidatedTransactionsForRescan
+ }
+
+ /** Test the property 'baseAsset' */
+ @Test
+ public void baseAssetTest() {
+ // TODO: test baseAsset
+ }
+
+ /** Test the property 'networkProtocol' */
+ @Test
+ public void networkProtocolTest() {
+ // TODO: test networkProtocol
+ }
+
+ /** Test the property 'txHashes' */
+ @Test
+ public void txHashesTest() {
+ // TODO: test txHashes
+ }
+}
diff --git a/src/test/java/com/fireblocks/sdk/model/AssetDoesNotExistHttpErrorTest.java b/src/test/java/com/fireblocks/sdk/model/CreateSigningKeyDtoProofOfOwnershipTest.java
similarity index 51%
rename from src/test/java/com/fireblocks/sdk/model/AssetDoesNotExistHttpErrorTest.java
rename to src/test/java/com/fireblocks/sdk/model/CreateSigningKeyDtoProofOfOwnershipTest.java
index 929f137..6f7a16a 100644
--- a/src/test/java/com/fireblocks/sdk/model/AssetDoesNotExistHttpErrorTest.java
+++ b/src/test/java/com/fireblocks/sdk/model/CreateSigningKeyDtoProofOfOwnershipTest.java
@@ -15,20 +15,15 @@
import org.junit.Test;
-/** Model tests for AssetDoesNotExistHttpError */
-public class AssetDoesNotExistHttpErrorTest {
- private final AssetDoesNotExistHttpError model = new AssetDoesNotExistHttpError();
+/** Model tests for CreateSigningKeyDtoProofOfOwnership */
+public class CreateSigningKeyDtoProofOfOwnershipTest {
+ private final CreateSigningKeyDtoProofOfOwnership model =
+ new CreateSigningKeyDtoProofOfOwnership();
- /** Model tests for AssetDoesNotExistHttpError */
+ /** Model tests for CreateSigningKeyDtoProofOfOwnership */
@Test
- public void testAssetDoesNotExistHttpError() {
- // TODO: test AssetDoesNotExistHttpError
- }
-
- /** Test the property 'statusCode' */
- @Test
- public void statusCodeTest() {
- // TODO: test statusCode
+ public void testCreateSigningKeyDtoProofOfOwnership() {
+ // TODO: test CreateSigningKeyDtoProofOfOwnership
}
/** Test the property 'message' */
@@ -37,9 +32,9 @@ public void messageTest() {
// TODO: test message
}
/** Test the property 'error' */
@Test
- public void errorTest() {
- // TODO: test error
+ public void signatureTest() {
+ // TODO: test signature
}
}
@@ -37,9 +32,9 @@ public void messageTest() {
// TODO: test message
}
- /** Test the property 'error' */
+ /** Test the property 'signature' */
diff --git a/src/test/java/com/fireblocks/sdk/model/GetAuditLogsResponseDTOTest.java b/src/test/java/com/fireblocks/sdk/model/GetLinkedCollectionsPaginatedResponseTest.java
similarity index 52%
rename from src/test/java/com/fireblocks/sdk/model/GetAuditLogsResponseDTOTest.java
rename to src/test/java/com/fireblocks/sdk/model/GetLinkedCollectionsPaginatedResponseTest.java
index 5620df9..3b0f974 100644
--- a/src/test/java/com/fireblocks/sdk/model/GetAuditLogsResponseDTOTest.java
+++ b/src/test/java/com/fireblocks/sdk/model/GetLinkedCollectionsPaginatedResponseTest.java
@@ -15,14 +15,15 @@
import org.junit.Test;
-/** Model tests for GetAuditLogsResponseDTO */
-public class GetAuditLogsResponseDTOTest {
- private final GetAuditLogsResponseDTO model = new GetAuditLogsResponseDTO();
+/** Model tests for GetLinkedCollectionsPaginatedResponse */
+public class GetLinkedCollectionsPaginatedResponseTest {
+ private final GetLinkedCollectionsPaginatedResponse model =
+ new GetLinkedCollectionsPaginatedResponse();
- /** Model tests for GetAuditLogsResponseDTO */
+ /** Model tests for GetLinkedCollectionsPaginatedResponse */
@Test
- public void testGetAuditLogsResponseDTO() {
- // TODO: test GetAuditLogsResponseDTO
+ public void testGetLinkedCollectionsPaginatedResponse() {
+ // TODO: test GetLinkedCollectionsPaginatedResponse
}
/** Test the property 'data' */
@@ -31,15 +32,9 @@ public void dataTest() {
// TODO: test data
}
/** Test the property 'total' */
@Test
- public void totalTest() {
- // TODO: test total
- }
-
- /** Test the property 'cursor' */
- @Test
- public void cursorTest() {
- // TODO: test cursor
+ public void nextTest() {
+ // TODO: test next
}
}
@@ -31,15 +32,9 @@ public void dataTest() {
// TODO: test data
}
- /** Test the property 'total' */
+ /** Test the property 'next' */